---
title: <span class="badge builder"></span> ExprTypeClassicConditionsConditionsEvaluator
---
# <span class="badge builder"></span> ExprTypeClassicConditionsConditionsEvaluator

## Constructor

```python
ExprTypeClassicConditionsConditionsEvaluator()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeClassicConditionsConditionsEvaluator
```

### <span class="badge object-method"></span> params

```python
def params(params: list[float]) -> typing.Self
```

### <span class="badge object-method"></span> type_val

e.g. "gt"

```python
def type_val(type_val: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsEvaluator](./object-ExprTypeClassicConditionsConditionsEvaluator.md)
